@@ -63,7 +63,7 @@
 
 ;; If `start-file-process' isn't defined, it gets an alias in tramp-compat.el.
 (when (eq (symbol-function 'start-file-process)
-	  (symbol-function 'tramp-handle-start-file-process))
+	  'tramp-handle-start-file-process)
   (defadvice executable-find
     (around tramp-advice-executable-find activate)
     "Invoke `tramp-handle-executable-find' for Tramp files."
@@ -408,7 +408,7 @@ Works only for relative file names and Tramp file names."
     (eval
      `(defadvice ,x
 	(around ,(intern (format "tramp-advice-%s" x)) activate)
-	,(format "Run `%s on a local default directory." x)
+	,(format "Run `%s' on a local default directory." x)
 	(let ((default-directory
 		(unhandled-file-name-directory default-directory)))
 	  ad-do-it)))
@@ -430,6 +430,63 @@ Works only for relative file names and Tramp file names."
    ispell-start-process
    jka-compr-call-process jka-compr-partial-uncompress))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+;; PC-expand-many-files needs special care-
+
+;; This function contributed by Ed Sabol
+(defun tramp-PC-expand-many-files (name)
+  "Like `PC-expand-many-files' for Tramp files."
+  (with-parsed-tramp-file-name name nil
+    (save-match-data
+      (if (or (string-match "\\*" name)
+	      (string-match "\\?" name)
+	      (string-match "\\[.*\\]" name))
+	  (progn
+	    (let (bufstr)
+	      ;; CCC: To do it right, we should quote certain characters
+	      ;; in the file name, but since the echo command is going to
+	      ;; break anyway when there are spaces in the file names, we
+	      ;; don't bother.
+	      ;;-(let ((comint-file-name-quote-list
+	      ;;-       (set-difference tramp-file-name-quote-list
+	      ;;-                       '(?\* ?\? ?[ ?]))))
+	      ;;-  (tramp-send-command
+	      ;;-   method user host
+	      ;;-   (format "echo %s" (comint-quote-filename localname))))
+	      (tramp-send-command v (format "echo %s" localname))
+	      (setq bufstr (buffer-substring
+			    (point-min) (tramp-compat-line-end-position)))
+	      (with-current-buffer (tramp-get-buffer v)
+		(goto-char (point-min))
+		(if (string-equal localname bufstr)
+		    nil
+		  (insert "(\"")
+		  (while (search-forward " " nil t)
+		    (delete-backward-char 1)
+		    (insert "\" \""))
+		  (goto-char (point-max))
+		  (delete-backward-char 1)
+		  (insert "\")")
+		  (goto-char (point-min))
+		  (mapcar
+		   (lambda (x) (tramp-make-tramp-file-name method user host x))
+		   (read (current-buffer)))))))
+	(list (expand-file-name name))))))
+
+(when (functionp 'PC-expand-many-files)
+  (eval-after-load "complete"
+    '(progn
+       (defadvice PC-expand-many-files
+	 (around tramp-advice-PC-expand-many-files (name) activate)
+	 "Invoke `tramp-PC-expand-many-files' for Tramp files."
+	 (if (tramp-tramp-file-p name)
+	     (setq ad-return-value (tramp-PC-expand-many-files name))
+	   ad-do-it))
+       (add-hook 'tramp-unload-hook
+		 '(lambda () (ad-unadvise 'PC-expand-many-files))))))
+
+
 (provide 'tramp-util)
 
 ;;; arch-tag: 500f9992-a44e-46d0-83a7-980799251808
