@@ -10,8 +10,8 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,17 +34,14 @@
 
 ;;; Code:
 
+(require 'tramp)
+(require 'tramp-compat)
+
 (require 'vc)
 ;; Old VC defines vc-rcs-release in vc.el, new VC requires extra module.
-(unless (boundp 'vc-rcs-release)
-  (require 'vc-rcs))
-(require 'tramp)
-
-;; Avoid byte-compiler warnings if the byte-compiler supports this.
-;; Currently, XEmacs supports this.
-(eval-when-compile
-  (when (featurep 'xemacs)
-    (byte-compiler-options (warnings (- unused-vars)))))
+(eval-and-compile
+  (unless (boundp 'vc-rcs-release)
+    (require 'vc-rcs)))
 
 ;; -- vc --
 ;; Wire ourselves into the VC infrastructure...
@@ -55,7 +52,11 @@
 
 ;; The following defadvice is no longer necessary after changes in VC
 ;; on 2006-01-25, Andre.
-(unless (fboundp 'process-file)
+
+;; That means either GNU Emacs >= 22 or the "new vc" package from XEmacs
+;; packages collection; as of 2007-09-06, test for availability of
+;; `vc-find-version' works for both of those cases.
+(unless (fboundp 'vc-find-version)
   (defadvice vc-user-login-name
     (around tramp-vc-user-login-name activate)
     "Support for files on remote machines accessed by Tramp."
@@ -72,7 +73,7 @@
 			       (tramp-make-tramp-temp-file v))))
 			 (unwind-protect
 			     (save-excursion
-			       (tramp-touch tmpfile (current-time))
+			       (set-file-times tmpfile (current-time))
 			       (tramp-send-command
 				v (format "chown %d %s" uid tmpfile))
 			       (setq ad-return-value
